@@ -89,6 +89,7 @@ public:
                 bool,
                 const IDebugger::Frame&,
                 int,
+                int,
                 const UString& /*cookie*/>& stopped_signal () const ;
 
     sigc::signal<void,
@@ -124,21 +125,21 @@ public:
 
     sigc::signal<void,
                  const UString&,
-                 const IDebugger::VariableSafePtr&,
+                 const IDebugger::VariableSafePtr,
                  const UString&>& variable_value_signal () const  ;
 
     sigc::signal<void,
-                 const VariableSafePtr&/*variable*/,
+                 const VariableSafePtr/*variable*/,
                  const UString& /*cookie*/>&
                                      variable_value_set_signal () const ;
 
-    sigc::signal<void, const UString&, const VariableSafePtr&, const UString&>&
+    sigc::signal<void, const UString&, const VariableSafePtr, const UString&>&
                                     pointed_variable_value_signal () const  ;
 
     sigc::signal<void, const UString&, const UString&, const UString&>&
                                         variable_type_signal () const ;
 
-    sigc::signal<void, const VariableSafePtr&, const UString&>&
+    sigc::signal<void, const VariableSafePtr, const UString&>&
                                     variable_type_set_signal () const ;
 
     sigc::signal<void, const VariableSafePtr, const UString&>
@@ -186,6 +187,7 @@ public:
                             bool has_frame,
                             const IDebugger::Frame &a_frame,
                             int a_thread_id,
+                            int a_breakpoint_number,
                             const UString &a_cookie);
     void on_detached_from_target_signal ();
 
@@ -276,15 +278,17 @@ public:
 
     void set_breakpoint (const UString &a_path,
                          gint a_line_num,
+                         const UString &a_condition,
+                         const UString &a_cookie)  ;
+
+    void set_breakpoint (const UString &a_func_name,
+                         const UString &a_condition,
                          const UString &a_cookie)  ;
 
     void list_breakpoints (const UString &a_cookie) ;
 
     map<int, IDebugger::BreakPoint>& get_cached_breakpoints () ;
 
-    void set_breakpoint (const UString &a_func_name,
-                         const UString &a_cookie)  ;
-
     void set_catch (const UString &a_event,
 					const UString &a_cookie)  ;
 
@@ -328,6 +332,9 @@ public:
     void evaluate_expression (const UString &a_expr,
                               const UString &a_cookie) ;
 
+    void call_function (const UString &a_call_expression,
+                        const UString &a_cookie="");
+
     void print_variable_value (const UString &a_var_name,
                               const UString &a_cookie) ;
 
